import { createParamDecorator, ExecutionContext } from '@nestjs/common';

/**
 * Decorator to extract user information from the request
 * 
 * Usage:
 * - @GetUser() user: any - Get the entire user object
 * - @GetUser('id') userId: string - Get a specific property from the user object
 */
export const GetUser = createParamDecorator(
  (data: string | undefined, ctx: ExecutionContext) => {
    const request = ctx.switchToHttp().getRequest();
    const user = request.user;

    // Return the specific property if data is provided, otherwise return the entire user object
    return data ? user?.[data] : user;
  },
);