import { 
  IsString, 
  IsNotEmpty, 
  IsOptional, 
  IsObject, 
  IsUUID, 
  IsEnum, 
  IsInt, 
  IsBoolean, 
  Min, 
  Max 
} from 'class-validator';
import { Type } from 'class-transformer';

/**
 * Enum for gender values
 */
export enum Gender {
  MALE = 'MALE',
  FEMALE = 'FEMALE',
  NON_BINARY = 'NON_BINARY',
}

/**
 * Enum for oral ease level values
 */
export enum OralEaseLevel {
  SHY = 'SHY',
  RESERVED = 'RESERVED',
  COMFORTABLE = 'COMFORTABLE',
}

/**
 * DTO for creating a new person
 */
export class CreatePersonDto {
  @IsString()
  @IsNotEmpty()
  firstName: string;

  @IsString()
  @IsNotEmpty()
  lastName: string;

  @IsEnum(Gender)
  @IsNotEmpty()
  gender: Gender;

  @IsInt()
  @Min(1)
  @Max(5)
  @Type(() => Number)
  technicalLevel: number;

  @IsBoolean()
  @Type(() => Boolean)
  hasTechnicalTraining: boolean;

  @IsInt()
  @Min(1)
  @Max(5)
  @Type(() => Number)
  frenchSpeakingLevel: number;

  @IsEnum(OralEaseLevel)
  @IsNotEmpty()
  oralEaseLevel: OralEaseLevel;

  @IsInt()
  @IsOptional()
  @Min(18)
  @Max(100)
  @Type(() => Number)
  age?: number;

  @IsUUID()
  @IsNotEmpty()
  projectId: string;

  @IsObject()
  @IsOptional()
  attributes?: Record<string, any>;
}